@@ -9,6 +9,7 @@ import asyncio
 from ai_kit.cli.registry import registry_instance
 from ai_kit import __version__  # Import version
 from ai_kit.shared_console import shared_console, shared_error_console
+from ai_kit.cli.commands.gitingest import gitingest_command
 
 # Configure basic logging
 logging.basicConfig(
@@ -133,26 +134,19 @@ def web_search(query: str, rerank_query: str, max_results: int, site: str):
     for result in results:
         pprint(result)
 
-    shared_console.print(f"[bold green]<thinking>[/bold green] Okay, now i need to use `ai-kit think {{ url: <url> }}` to think about the results.")
-
 @web.command(name="fetch")
-@click.argument("url")
-@click.option(
-    "--no-links-table",
-    is_flag=True,
-    help="Skip displaying the table of internal links",
-)
+@click.argument("urls", nargs=-1)
 @registry_instance.add(
     name="web fetch",
-    description="Fetch and display content from a specific URL.",
-    usage="ai-kit web fetch <url> [--raw] [--no-links-table]",
+    description="Fetch and display content from a list of URLs.",
+    usage="ai-kit web fetch <url1> <url2> <url3>",
 )
-def web_fetch(url: str, no_links_table: bool):
+def web_fetch(urls: list[str], no_links_table: bool = True):
     """Fetch and display content from a specific URL."""
     from ai_kit.cli.commands.web.fetch import fetch_web
     
     try:
-       asyncio.run(fetch_web(url, no_links_table=no_links_table))
+       asyncio.run(fetch_web(urls, no_links_table=no_links_table))
     except Exception as e:
         shared_error_console.print(f"[red]Error fetching URL: {e}[/red]")
         sys.exit(1)
@@ -208,7 +202,7 @@ def web_crawl(seed_url: str, output_dir: str | None, site_dir: str | None, max_u
     "--deepthink-model",
     "-dm",
     type=str,
-    default="r1-together",  
+    default="r1",  
     help="Model to use for deep thinking",
 )
 @main.command()
@@ -286,4 +280,32 @@ def browse(instruction: str, headless: bool):
         asyncio.run(browse_command(instruction, headless))
     except Exception as e:
         shared_error_console.print(f"[red]Error: {str(e)}[/red]")
-        raise click.Abort() 
\ No newline at end of file
+        raise click.Abort()
+
+# ! disabling this until fixed
+# @main.command()
+@click.argument("repo")
+@click.option(
+    "--output-dir", "-d",
+    type=str,
+    help="Directory to save multiple output files (overrides --output-file)",
+    default=".",
+)
+@registry_instance.add(
+    name="gitingest",
+    description="Analyze a Git repository and create a prompt-friendly text digest.",
+    usage="ai-kit gitingest <repo> [-o output_file] [-d output_dir]",
+)
+def gitingest(repo: str, output_dir: str):
+    """Analyze a Git repository and create a prompt-friendly text digest.
+    
+    When using --output-dir, the following files will be created:
+    - summary.md: Repository analysis summary
+    - tree.md: Directory structure
+    - content.md: Repository content with markdown formatting
+    - digest.txt: Complete digest in plain text
+    """
+    asyncio.run(gitingest_command(
+        repo=repo,
+        output_dir=output_dir,
+    )) 
\ No newline at end of file
